@@ -15,7 +15,7 @@ from itertools import islice
 # Global Constants And Variables
 ###############################################################################
 
-log = logging.getLogger('pyscp.orm')
+log = logging.getLogger("pyscp.orm")
 pool = concurrent.futures.ThreadPoolExecutor(max_workers=1)
 queue = queue.Queue()
 
@@ -24,6 +24,7 @@ def queue_execution(fn, args=(), kw={}):
     queue.put(dict(fn=fn, args=args, kw=kw))
     pool.submit(async_write)
 
+
 ###############################################################################
 # Database ORM Classes
 ###############################################################################
@@ -32,7 +33,6 @@ db = peewee.Proxy()
 
 
 class BaseModel(peewee.Model):
-
     class Meta:
         database = db
 
@@ -42,7 +42,7 @@ class BaseModel(peewee.Model):
 
     @classmethod
     def create_table(cls):
-        if not hasattr(cls, '_id_cache'):
+        if not hasattr(cls, "_id_cache"):
             cls._id_cache = []
         queue_execution(fn=super().create_table, args=(True,))
 
@@ -53,11 +53,12 @@ class BaseModel(peewee.Model):
         while chunk:
             queue_execution(
                 fn=lambda x: super(BaseModel, cls).insert_many(x).execute(),
-                args=(chunk, ))
+                args=(chunk,),
+            )
             chunk = list(islice(data_iter, 500))
 
     @classmethod
-    def convert_to_id(cls, data, key='user'):
+    def convert_to_id(cls, data, key="user"):
         for row in data:
             if row[key] not in cls._id_cache:
                 cls._id_cache.append(row[key])
@@ -66,9 +67,12 @@ class BaseModel(peewee.Model):
 
     @classmethod
     def write_ids(cls, field_name):
-        cls.insert_many([
-            {'id': cls._id_cache.index(value) + 1, field_name: value}
-            for value in set(cls._id_cache)])
+        cls.insert_many(
+            [
+                {"id": cls._id_cache.index(value) + 1, field_name: value}
+                for value in set(cls._id_cache)
+            ]
+        )
         cls._id_cache.clear()
 
 
@@ -86,8 +90,7 @@ class ForumThread(BaseModel):
 class Page(BaseModel):
     url = peewee.CharField(unique=True)
     source = peewee.TextField()
-    thread = peewee.ForeignKeyField(
-        ForumThread, related_name='page', null=True)
+    thread = peewee.ForeignKeyField(ForumThread, related_name="page", null=True)
 
 
 class User(BaseModel):
@@ -95,24 +98,23 @@ class User(BaseModel):
 
 
 class Revision(BaseModel):
-    page = peewee.ForeignKeyField(Page, related_name='revisions', index=True)
-    user = peewee.ForeignKeyField(User, related_name='revisions', index=True)
+    page = peewee.ForeignKeyField(Page, related_name="revisions", index=True)
+    user = peewee.ForeignKeyField(User, related_name="revisions", index=True)
     number = peewee.IntegerField()
     time = peewee.DateTimeField()
     comment = peewee.CharField(null=True)
 
 
 class Vote(BaseModel):
-    page = peewee.ForeignKeyField(Page, related_name='votes', index=True)
-    user = peewee.ForeignKeyField(User, related_name='votes', index=True)
+    page = peewee.ForeignKeyField(Page, related_name="votes", index=True)
+    user = peewee.ForeignKeyField(User, related_name="votes", index=True)
     value = peewee.IntegerField()
 
 
 class ForumPost(BaseModel):
-    thread = peewee.ForeignKeyField(
-        ForumThread, related_name='posts', index=True)
-    user = peewee.ForeignKeyField(User, related_name='posts', index=True)
-    parent = peewee.ForeignKeyField('self', null=True)
+    thread = peewee.ForeignKeyField(ForumThread, related_name="posts", index=True)
+    user = peewee.ForeignKeyField(User, related_name="posts", index=True)
+    parent = peewee.ForeignKeyField("self", null=True)
     title = peewee.CharField(null=True)
     time = peewee.DateTimeField()
     content = peewee.TextField()
@@ -123,8 +125,8 @@ class Tag(BaseModel):
 
 
 class PageTag(BaseModel):
-    page = peewee.ForeignKeyField(Page, related_name='tags', index=True)
-    tag = peewee.ForeignKeyField(Tag, related_name='pages', index=True)
+    page = peewee.ForeignKeyField(Page, related_name="tags", index=True)
+    tag = peewee.ForeignKeyField(Tag, related_name="pages", index=True)
 
 
 class OverrideType(BaseModel):
@@ -148,6 +150,7 @@ class Image(BaseModel):
     status = peewee.ForeignKeyField(ImageStatus)
     notes = peewee.TextField(null=True)
 
+
 ###############################################################################
 # Helper Functions
 ###############################################################################
@@ -157,7 +160,7 @@ def async_write(buffer=[]):
     item = queue.get()
     buffer.append(item)
     if len(buffer) > 500 or queue.empty():
-        log.debug('Processing {} queue items.'.format(len(buffer)))
+        log.debug("Processing {} queue items.".format(len(buffer)))
         with db.transaction():
             write_buffer(buffer)
         buffer.clear()
@@ -166,11 +169,9 @@ def async_write(buffer=[]):
 def write_buffer(buffer):
     for item in buffer:
         try:
-            item['fn'](*item.get('args', ()), **item.get('kw', {}))
+            item["fn"](*item.get("args", ()), **item.get("kw", {}))
         except:
-            log.exception(
-                'Exception while processing queue item: {}'
-                .format(item))
+            log.exception("Exception while processing queue item: {}".format(item))
         queue.task_done()
 
 
@@ -180,7 +181,7 @@ def create_tables(*tables):
 
 
 def connect(dbpath):
-    log.info('Connecting to the database at {}'.format(dbpath))
+    log.info("Connecting to the database at {}".format(dbpath))
     db.initialize(peewee.SqliteDatabase(dbpath))
     db.connect()
 
@@ -192,9 +193,9 @@ def connect(dbpath):
 
 def votes_by_user(user):
     up, down = [], []
-    for vote in (Vote.select().join(User).where(User.name == user)):
+    for vote in Vote.select().join(User).where(User.name == user):
         if vote.value == 1:
             up.append(vote.page.url)
         else:
             down.append(vote.page.url)
-    return {'+': up, '-': down}
+    return {"+": up, "-": down}
