@@ -23,7 +23,6 @@ import inspect
 
 
 class Call:
-
     def __init__(self, func, args, kwargs):
         self.func, self.args, self.kwargs = func, args, kwargs
 
@@ -34,9 +33,11 @@ class Call:
 def decorator(deco):
     spec = inspect.getargspec(deco)
     if len(spec.args) > 1 or spec.varargs or spec.keywords:
+
         @functools.wraps(deco)
         def _fab(*dargs, **dkwargs):
             return make_decorator(deco, *dargs, **dkwargs)
+
         return _fab
     else:
         return functools.wraps(deco)(make_decorator(deco))
@@ -48,9 +49,12 @@ def make_decorator(deco, *dargs, **dkwargs):
         def wrapper(*args, **kwargs):
             call = Call(func, args, kwargs)
             return deco(call, *dargs, **dkwargs)
+
         return wrapper
+
     return _decorator
 
+
 ###############################################################################
 
 
@@ -81,7 +85,7 @@ def log_errors(call, logger=print):
         return call()
     except Exception as error:
         logger(error)
-        raise(error)
+        raise (error)
 
 
 @decorator
@@ -93,28 +97,27 @@ def decochain(call, *decs):
 
 
 class cached_property:
-
     def __init__(self, func):
         self.func = func
         functools.update_wrapper(self, func)
 
     def __get__(self, obj, cls):
-        if not hasattr(obj, '_cache'):
+        if not hasattr(obj, "_cache"):
             obj._cache = {}
         if self.func.__name__ not in obj._cache:
             obj._cache[self.func.__name__] = self.func(obj)
         return obj._cache[self.func.__name__]
 
+
 ###############################################################################
 
 
 def split(text, delimeters):
-    pattern = '|'.join(map(re.escape, delimeters))
+    pattern = "|".join(map(re.escape, delimeters))
     return re.split(pattern, text)
 
 
 class ProgressBar:
-
     def __init__(self, title, max_value):
         self.title = title
         self.max_value = max_value
@@ -127,19 +130,22 @@ class ProgressBar:
         threading.Thread(target=self.run).start()
 
     def update(self):
-        print(self.line() + '\r', end='')
+        print(self.line() + "\r", end="")
 
     def line(self):
         filled = 40 * self.value / self.max_value
-        parts = ' ▏▎▍▌▋▊▉'
+        parts = " ▏▎▍▌▋▊▉"
         current = int(filled * len(parts)) % len(parts)
-        bar = '█' * int(filled) + parts[current] + ' ' * 40
+        bar = "█" * int(filled) + parts[current] + " " * 40
         tm = time.gmtime(time.time() - self.time_started)
-        return '{} |{}| {:>3}% ({}:{:02}:{:02})   '.format(
+        return "{} |{}| {:>3}% ({}:{:02}:{:02})   ".format(
             self.title,
             bar[:40],
             100 * self.value // self.max_value,
-            tm.tm_hour, tm.tm_min, tm.tm_sec)
+            tm.tm_hour,
+            tm.tm_min,
+            tm.tm_sec,
+        )
 
     def run(self):
         while not self.finished:
@@ -157,7 +163,7 @@ class ProgressBar:
 
 def pbar(it, title=None, max=None):
     max = len(it) if max is None else max
-    title = '' if title is None else title + ' '
+    title = "" if title is None else title + " "
     bar = ProgressBar(title, max)
     bar.start()
     for i in it:
@@ -166,11 +172,11 @@ def pbar(it, title=None, max=None):
         bar.update()
     bar.stop()
 
+
 ###############################################################################
 
 
 class LogCount:
-
     def __init__(self):
         self.count = 1
 
@@ -181,29 +187,31 @@ class LogCount:
 
 
 def log_sql_debug():
-    logger = logging.getLogger('peewee')
+    logger = logging.getLogger("peewee")
     logger.setLevel(logging.DEBUG)
     logger.addFilter(LogCount())
     term = logging.StreamHandler()
-    term.setFormatter(logging.Formatter('{count} {message}', style='{'))
+    term.setFormatter(logging.Formatter("{count} {message}", style="{"))
     logger.addHandler(term)
 
 
 def default_logging(debug=False):
     term = logging.StreamHandler()
-    file = logging.FileHandler('pyscp.log', mode='a', delay=True)
+    file = logging.FileHandler("pyscp.log", mode="a", delay=True)
     if debug:
         term.setLevel(logging.DEBUG)
         file.setLevel(logging.DEBUG)
     else:
         term.setLevel(logging.INFO)
         file.setLevel(logging.INFO)
-    term.setFormatter(logging.Formatter('{message}', style='{'))
+    term.setFormatter(logging.Formatter("{message}", style="{"))
     file.setFormatter(
-        logging.Formatter('{asctime} {levelname:8s} {message}', style='{'))
-    logger = logging.getLogger('pyscp')
+        logging.Formatter("{asctime} {levelname:8s} {message}", style="{")
+    )
+    logger = logging.getLogger("pyscp")
     logger.setLevel(logging.DEBUG)
     logger.addHandler(term)
     logger.addHandler(file)
 
+
 ###############################################################################
